pub(crate) enum LinePathEl {
MoveTo(Point),
LineTo(Point),
}Expand description
The element of a path made of lines.
Each subpath must start with a MoveTo. Closing of subpaths is not supported, and subpaths are
not closed implicitly when a new subpath (with MoveTo) is started. It is expected that closed
subpaths are watertight in the sense that the last LineTo matches exactly with the first
MoveTo.
This intentionally allows for non-watertight subpaths, as, e.g., lines that are fully outside of the viewport do not need to be drawn.
See PathEl for a more general-purpose path element type.
Variants